@@ -70,6 +70,14 @@ struct Application {
     descriptor_pool: asche::DescriptorPool,
 }
 
+impl Drop for Application {
+    fn drop(&mut self) {
+        self.device
+            .wait_idle()
+            .expect("couldn't wait for device to become idle while dropping")
+    }
+}
+
 impl Application {
     fn new(
         device: asche::Device,
